@@ -1,7 +1,5 @@
 import click
-
-
-# from .visualsim import *
+from .visualsim import *
 
 def duck_art():
     duck = """
